# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
)


def lazy_import():
    from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
    from datadog_api_client.v1.model.dashboard_reflow_type import DashboardReflowType
    from datadog_api_client.v1.model.dashboard_template_variable import DashboardTemplateVariable
    from datadog_api_client.v1.model.dashboard_template_variable_preset import DashboardTemplateVariablePreset
    from datadog_api_client.v1.model.widget import Widget

    globals()["DashboardLayoutType"] = DashboardLayoutType
    globals()["DashboardReflowType"] = DashboardReflowType
    globals()["DashboardTemplateVariable"] = DashboardTemplateVariable
    globals()["DashboardTemplateVariablePreset"] = DashboardTemplateVariablePreset
    globals()["Widget"] = Widget


class Dashboard(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "author_handle": (str,),
            "author_name": (
                str,
                none_type,
            ),
            "created_at": (datetime,),
            "description": (
                str,
                none_type,
            ),
            "id": (str,),
            "is_read_only": (bool,),
            "layout_type": (DashboardLayoutType,),
            "modified_at": (datetime,),
            "notify_list": (
                [str],
                none_type,
            ),
            "reflow_type": (DashboardReflowType,),
            "restricted_roles": ([str],),
            "template_variable_presets": (
                [DashboardTemplateVariablePreset],
                none_type,
            ),
            "template_variables": (
                [DashboardTemplateVariable],
                none_type,
            ),
            "title": (str,),
            "url": (str,),
            "widgets": ([Widget],),
        }

    attribute_map = {
        "layout_type": "layout_type",
        "title": "title",
        "widgets": "widgets",
        "author_handle": "author_handle",
        "author_name": "author_name",
        "created_at": "created_at",
        "description": "description",
        "id": "id",
        "is_read_only": "is_read_only",
        "modified_at": "modified_at",
        "notify_list": "notify_list",
        "reflow_type": "reflow_type",
        "restricted_roles": "restricted_roles",
        "template_variable_presets": "template_variable_presets",
        "template_variables": "template_variables",
        "url": "url",
    }

    read_only_vars = {
        "author_handle",
        "author_name",
        "created_at",
        "id",
        "modified_at",
        "url",
    }

    def __init__(self, layout_type, title, widgets, *args, **kwargs):
        """Dashboard - a model defined in OpenAPI

        Args:
            layout_type (DashboardLayoutType):
            title (str): Title of the dashboard.
            widgets ([Widget]): List of widgets to display on the dashboard.

        Keyword Args:
            author_handle (str): [optional] Identifier of the dashboard author.
            author_name (str, none_type): [optional] Name of the dashboard author.
            created_at (datetime): [optional] Creation date of the dashboard.
            description (str, none_type): [optional] Description of the dashboard.
            id (str): [optional] ID of the dashboard.
            is_read_only (bool): [optional] Whether this dashboard is read-only. If True, only the author and admins can make changes to it. Prefer using `restricted_roles` to manage write authorization. If omitted the server will use the default value of False.
            modified_at (datetime): [optional] Modification date of the dashboard.
            notify_list ([str], none_type): [optional] List of handles of users to notify when changes are made to this dashboard.
            reflow_type (DashboardReflowType): [optional]
            restricted_roles ([str]): [optional] A list of role identifiers. Only the author and users associated with at least one of these roles can edit this dashboard.
            template_variable_presets ([DashboardTemplateVariablePreset], none_type): [optional] Array of template variables saved views.
            template_variables ([DashboardTemplateVariable], none_type): [optional] List of template variables for this dashboard.
            url (str): [optional] The URL of the dashboard.
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.layout_type = layout_type
        self.title = title
        self.widgets = widgets

    @classmethod
    def _from_openapi_data(cls, layout_type, title, widgets, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(Dashboard, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.layout_type = layout_type
        self.title = title
        self.widgets = widgets
        return self
