# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.logs_exclusion import LogsExclusion
    from datadog_api_client.v1.model.logs_filter import LogsFilter

    globals()["LogsExclusion"] = LogsExclusion
    globals()["LogsFilter"] = LogsFilter


class LogsIndexUpdateRequest(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "daily_limit": (int,),
            "disable_daily_limit": (bool,),
            "exclusion_filters": ([LogsExclusion],),
            "filter": (LogsFilter,),
            "num_retention_days": (int,),
        }

    attribute_map = {
        "filter": "filter",
        "daily_limit": "daily_limit",
        "disable_daily_limit": "disable_daily_limit",
        "exclusion_filters": "exclusion_filters",
        "num_retention_days": "num_retention_days",
    }

    read_only_vars = {}

    def __init__(self, filter, *args, **kwargs):
        """LogsIndexUpdateRequest - a model defined in OpenAPI

        Args:
            filter (LogsFilter):

        Keyword Args:
            daily_limit (int): [optional] The number of log events you can send in this index per day before you are rate-limited.
            disable_daily_limit (bool): [optional] If true, sets the `daily_limit` value to null and the index is not limited on a daily basis (any specified `daily_limit` value in the request is ignored). If false or omitted, the index's current `daily_limit` is maintained.
            exclusion_filters ([LogsExclusion]): [optional] An array of exclusion objects. The logs are tested against the query of each filter, following the order of the array. Only the first matching active exclusion matters, others (if any) are ignored.
            num_retention_days (int): [optional] The number of days before logs are deleted from this index. Available values depend on retention plans specified in your organization's contract/subscriptions.  **Note:** Changing the retention for an index adjusts the length of retention for all logs already in this index. It may also affect billing.
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.filter = filter

    @classmethod
    def _from_openapi_data(cls, filter, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(LogsIndexUpdateRequest, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.filter = filter
        return self
