# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelComposed,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.logs_arithmetic_processor import LogsArithmeticProcessor
    from datadog_api_client.v1.model.logs_attribute_remapper import LogsAttributeRemapper
    from datadog_api_client.v1.model.logs_category_processor import LogsCategoryProcessor
    from datadog_api_client.v1.model.logs_category_processor_category import LogsCategoryProcessorCategory
    from datadog_api_client.v1.model.logs_date_remapper import LogsDateRemapper
    from datadog_api_client.v1.model.logs_filter import LogsFilter
    from datadog_api_client.v1.model.logs_geo_ip_parser import LogsGeoIPParser
    from datadog_api_client.v1.model.logs_grok_parser import LogsGrokParser
    from datadog_api_client.v1.model.logs_grok_parser_rules import LogsGrokParserRules
    from datadog_api_client.v1.model.logs_lookup_processor import LogsLookupProcessor
    from datadog_api_client.v1.model.logs_message_remapper import LogsMessageRemapper
    from datadog_api_client.v1.model.logs_pipeline_processor import LogsPipelineProcessor
    from datadog_api_client.v1.model.logs_service_remapper import LogsServiceRemapper
    from datadog_api_client.v1.model.logs_status_remapper import LogsStatusRemapper
    from datadog_api_client.v1.model.logs_string_builder_processor import LogsStringBuilderProcessor
    from datadog_api_client.v1.model.logs_trace_remapper import LogsTraceRemapper
    from datadog_api_client.v1.model.logs_trace_remapper_type import LogsTraceRemapperType
    from datadog_api_client.v1.model.logs_url_parser import LogsURLParser
    from datadog_api_client.v1.model.logs_user_agent_parser import LogsUserAgentParser
    from datadog_api_client.v1.model.target_format_type import TargetFormatType

    globals()["LogsArithmeticProcessor"] = LogsArithmeticProcessor
    globals()["LogsAttributeRemapper"] = LogsAttributeRemapper
    globals()["LogsCategoryProcessor"] = LogsCategoryProcessor
    globals()["LogsCategoryProcessorCategory"] = LogsCategoryProcessorCategory
    globals()["LogsDateRemapper"] = LogsDateRemapper
    globals()["LogsFilter"] = LogsFilter
    globals()["LogsGeoIPParser"] = LogsGeoIPParser
    globals()["LogsGrokParser"] = LogsGrokParser
    globals()["LogsGrokParserRules"] = LogsGrokParserRules
    globals()["LogsLookupProcessor"] = LogsLookupProcessor
    globals()["LogsMessageRemapper"] = LogsMessageRemapper
    globals()["LogsPipelineProcessor"] = LogsPipelineProcessor
    globals()["LogsServiceRemapper"] = LogsServiceRemapper
    globals()["LogsStatusRemapper"] = LogsStatusRemapper
    globals()["LogsStringBuilderProcessor"] = LogsStringBuilderProcessor
    globals()["LogsTraceRemapper"] = LogsTraceRemapper
    globals()["LogsTraceRemapperType"] = LogsTraceRemapperType
    globals()["LogsURLParser"] = LogsURLParser
    globals()["LogsUserAgentParser"] = LogsUserAgentParser
    globals()["TargetFormatType"] = TargetFormatType


class LogsProcessor(ModelComposed):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    validations = {
        "samples": {
            "max_items": 5,
        },
    }

    @cached_property
    def openapi_types():
        return {}

    def __init__(self, *args, **kwargs):
        """LogsProcessor - a model defined in OpenAPI

        Keyword Args:
            is_enabled (bool): [optional] Whether or not the processor is enabled. If omitted the server will use the default value of False.
            name (str): [optional] Name of the processor.
            samples ([str]): [optional] List of sample logs to test this grok parser.
            override_on_conflict (bool): [optional] Override or not the target element if already set, If omitted the server will use the default value of False.
            preserve_source (bool): [optional] Remove or preserve the remapped source element. If omitted the server will use the default value of False.
            source_type (str): [optional] Defines if the sources are from log `attribute` or `tag`. If omitted the server will use the default value of "attribute".
            target_format (TargetFormatType): [optional]
            target_type (str): [optional] Defines if the final attribute or tag name is from log `attribute` or `tag`. If omitted the server will use the default value of "attribute".
            normalize_ending_slashes (bool, none_type): [optional] Normalize the ending slashes or not. If omitted the server will use the default value of False.
            is_encoded (bool): [optional] Define if the source attribute is URL encoded or not. If omitted the server will use the default value of False.
            is_replace_missing (bool): [optional] If true, it replaces all missing attributes of `template` by an empty string. If `false` (default), skips the operation for missing attributes. If omitted the server will use the default value of False.
            filter (LogsFilter): [optional]
            processors ([LogsProcessor]): [optional] Ordered list of processors in this pipeline.
            default_lookup (str): [optional] Value to set the target attribute if the source value is not found in the list.
            grok (LogsGrokParserRules): [optional]
            source (str): [optional] Source attribute used to perform the lookup.
            type (LogsTraceRemapperType): [optional]
            sources ([str]): [optional] Array of source attributes. If omitted the server will use the default value of ["dd.trace_id"].
            target (str): [optional] Name of the attribute that contains the corresponding value in the mapping list or the `default_lookup` if not found in the mapping list.
            categories ([LogsCategoryProcessorCategory]): [optional] Array of filters to match or not a log and their corresponding `name`to assign a custom value to the log.
            expression (str): [optional] Arithmetic operation between one or more log attributes.
            template (str): [optional] A formula with one or more attributes and raw text.
            lookup_table ([str]): [optional] Mapping table of values for the source attribute and their associated target attribute values, formatted as `[\"source_key1,target_value1\", \"source_key2,target_value2\"]`
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(LogsProcessor, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

    @cached_property
    def _composed_schemas():
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        lazy_import()
        return {
            "anyOf": [],
            "allOf": [],
            "oneOf": [
                LogsArithmeticProcessor,
                LogsAttributeRemapper,
                LogsCategoryProcessor,
                LogsDateRemapper,
                LogsGeoIPParser,
                LogsGrokParser,
                LogsLookupProcessor,
                LogsMessageRemapper,
                LogsPipelineProcessor,
                LogsServiceRemapper,
                LogsStatusRemapper,
                LogsStringBuilderProcessor,
                LogsTraceRemapper,
                LogsURLParser,
                LogsUserAgentParser,
            ],
        }
