# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
)


def lazy_import():
    from datadog_api_client.v1.model.synthetics_ssl_certificate_issuer import SyntheticsSSLCertificateIssuer
    from datadog_api_client.v1.model.synthetics_ssl_certificate_subject import SyntheticsSSLCertificateSubject

    globals()["SyntheticsSSLCertificateIssuer"] = SyntheticsSSLCertificateIssuer
    globals()["SyntheticsSSLCertificateSubject"] = SyntheticsSSLCertificateSubject


class SyntheticsSSLCertificate(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "cipher": (str,),
            "exponent": (float,),
            "ext_key_usage": ([str],),
            "fingerprint": (str,),
            "fingerprint256": (str,),
            "issuer": (SyntheticsSSLCertificateIssuer,),
            "modulus": (str,),
            "protocol": (str,),
            "serial_number": (str,),
            "subject": (SyntheticsSSLCertificateSubject,),
            "valid_from": (datetime,),
            "valid_to": (datetime,),
        }

    attribute_map = {
        "cipher": "cipher",
        "exponent": "exponent",
        "ext_key_usage": "extKeyUsage",
        "fingerprint": "fingerprint",
        "fingerprint256": "fingerprint256",
        "issuer": "issuer",
        "modulus": "modulus",
        "protocol": "protocol",
        "serial_number": "serialNumber",
        "subject": "subject",
        "valid_from": "validFrom",
        "valid_to": "validTo",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """SyntheticsSSLCertificate - a model defined in OpenAPI

        Keyword Args:
            cipher (str): [optional] Cipher used for the connection.
            exponent (float): [optional] Exponent associated to the certificate.
            ext_key_usage ([str]): [optional] Array of extensions and details used for the certificate.
            fingerprint (str): [optional] MD5 digest of the DER-encoded Certificate information.
            fingerprint256 (str): [optional] SHA-1 digest of the DER-encoded Certificate information.
            issuer (SyntheticsSSLCertificateIssuer): [optional]
            modulus (str): [optional] Modulus associated to the SSL certificate private key.
            protocol (str): [optional] TLS protocol used for the test.
            serial_number (str): [optional] Serial Number assigned by Symantec to the SSL certificate.
            subject (SyntheticsSSLCertificateSubject): [optional]
            valid_from (datetime): [optional] Date from which the SSL certificate is valid.
            valid_to (datetime): [optional] Date until which the SSL certificate is valid.
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SyntheticsSSLCertificate, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
