# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
)


def lazy_import():
    from datadog_api_client.v1.model.synthetics_browser_error import SyntheticsBrowserError
    from datadog_api_client.v1.model.synthetics_check_type import SyntheticsCheckType
    from datadog_api_client.v1.model.synthetics_core_web_vitals import SyntheticsCoreWebVitals
    from datadog_api_client.v1.model.synthetics_playing_tab import SyntheticsPlayingTab
    from datadog_api_client.v1.model.synthetics_step_detail_warning import SyntheticsStepDetailWarning
    from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType

    globals()["SyntheticsBrowserError"] = SyntheticsBrowserError
    globals()["SyntheticsCheckType"] = SyntheticsCheckType
    globals()["SyntheticsCoreWebVitals"] = SyntheticsCoreWebVitals
    globals()["SyntheticsPlayingTab"] = SyntheticsPlayingTab
    globals()["SyntheticsStepDetailWarning"] = SyntheticsStepDetailWarning
    globals()["SyntheticsStepType"] = SyntheticsStepType


class SyntheticsStepDetail(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "browser_errors": ([SyntheticsBrowserError],),
            "check_type": (SyntheticsCheckType,),
            "description": (str,),
            "duration": (float,),
            "error": (str,),
            "playing_tab": (SyntheticsPlayingTab,),
            "screenshot_bucket_key": (bool,),
            "skipped": (bool,),
            "snapshot_bucket_key": (bool,),
            "step_id": (int,),
            "sub_test_step_details": ([SyntheticsStepDetail],),
            "time_to_interactive": (float,),
            "type": (SyntheticsStepType,),
            "url": (str,),
            "value": (
                bool,
                date,
                datetime,
                dict,
                float,
                int,
                list,
                str,
                none_type,
            ),
            "vitals_metrics": ([SyntheticsCoreWebVitals],),
            "warnings": ([SyntheticsStepDetailWarning],),
        }

    attribute_map = {
        "browser_errors": "browserErrors",
        "check_type": "checkType",
        "description": "description",
        "duration": "duration",
        "error": "error",
        "playing_tab": "playingTab",
        "screenshot_bucket_key": "screenshotBucketKey",
        "skipped": "skipped",
        "snapshot_bucket_key": "snapshotBucketKey",
        "step_id": "stepId",
        "sub_test_step_details": "subTestStepDetails",
        "time_to_interactive": "timeToInteractive",
        "type": "type",
        "url": "url",
        "value": "value",
        "vitals_metrics": "vitalsMetrics",
        "warnings": "warnings",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """SyntheticsStepDetail - a model defined in OpenAPI

        Keyword Args:
            browser_errors ([SyntheticsBrowserError]): [optional] Array of errors collected for a browser test.
            check_type (SyntheticsCheckType): [optional]
            description (str): [optional] Description of the test.
            duration (float): [optional] Total duration in millisecond of the test.
            error (str): [optional] Error returned by the test.
            playing_tab (SyntheticsPlayingTab): [optional]
            screenshot_bucket_key (bool): [optional] Whether or not screenshots where collected by the test.
            skipped (bool): [optional] Whether or not to skip this step.
            snapshot_bucket_key (bool): [optional] Whether or not snapshots where collected by the test.
            step_id (int): [optional] The step ID.
            sub_test_step_details ([SyntheticsStepDetail]): [optional] If this steps include a sub-test. [Subtests documentation](https://docs.datadoghq.com/synthetics/browser_tests/advanced_options/#subtests).
            time_to_interactive (float): [optional] Time before starting the step.
            type (SyntheticsStepType): [optional]
            url (str): [optional] URL to perform the step against.
            value (bool, date, datetime, dict, float, int, list, str, none_type): [optional] Value for the step.
            vitals_metrics ([SyntheticsCoreWebVitals]): [optional] Array of Core Web Vitals metrics for the step.
            warnings ([SyntheticsStepDetailWarning]): [optional] Warning collected that didn't failed the step.
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SyntheticsStepDetail, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
