# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v2.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
)


def lazy_import():
    from datadog_api_client.v2.model.incident_field_attributes import IncidentFieldAttributes
    from datadog_api_client.v2.model.incident_notification_handle import IncidentNotificationHandle

    globals()["IncidentFieldAttributes"] = IncidentFieldAttributes
    globals()["IncidentNotificationHandle"] = IncidentNotificationHandle


class IncidentUpdateAttributes(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "customer_impact_end": (
                datetime,
                none_type,
            ),
            "customer_impact_scope": (str,),
            "customer_impact_start": (
                datetime,
                none_type,
            ),
            "customer_impacted": (bool,),
            "detected": (
                datetime,
                none_type,
            ),
            "fields": ({str: (IncidentFieldAttributes,)},),
            "notification_handles": ([IncidentNotificationHandle],),
            "resolved": (
                datetime,
                none_type,
            ),
            "title": (str,),
        }

    attribute_map = {
        "customer_impact_end": "customer_impact_end",
        "customer_impact_scope": "customer_impact_scope",
        "customer_impact_start": "customer_impact_start",
        "customer_impacted": "customer_impacted",
        "detected": "detected",
        "fields": "fields",
        "notification_handles": "notification_handles",
        "resolved": "resolved",
        "title": "title",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """IncidentUpdateAttributes - a model defined in OpenAPI

        Keyword Args:
            customer_impact_end (datetime, none_type): [optional] Timestamp when customers were no longer impacted by the incident.
            customer_impact_scope (str): [optional] A summary of the impact customers experienced during the incident.
            customer_impact_start (datetime, none_type): [optional] Timestamp when customers began being impacted by the incident.
            customer_impacted (bool): [optional] A flag indicating whether the incident caused customer impact.
            detected (datetime, none_type): [optional] Timestamp when the incident was detected.
            fields ({str: (IncidentFieldAttributes,)}): [optional] A condensed view of the user-defined fields for which to update selections.
            notification_handles ([IncidentNotificationHandle]): [optional] Notification handles that will be notified of the incident during update.
            resolved (datetime, none_type): [optional] Timestamp when the incident's state was set to resolved.
            title (str): [optional] The title of the incident, which summarizes what happened.
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(IncidentUpdateAttributes, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
