# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v2.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v2.model.security_monitoring_filter import SecurityMonitoringFilter
    from datadog_api_client.v2.model.security_monitoring_rule_case_create import SecurityMonitoringRuleCaseCreate
    from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
    from datadog_api_client.v2.model.security_monitoring_rule_query_create import SecurityMonitoringRuleQueryCreate
    from datadog_api_client.v2.model.security_monitoring_rule_type_create import SecurityMonitoringRuleTypeCreate

    globals()["SecurityMonitoringFilter"] = SecurityMonitoringFilter
    globals()["SecurityMonitoringRuleCaseCreate"] = SecurityMonitoringRuleCaseCreate
    globals()["SecurityMonitoringRuleOptions"] = SecurityMonitoringRuleOptions
    globals()["SecurityMonitoringRuleQueryCreate"] = SecurityMonitoringRuleQueryCreate
    globals()["SecurityMonitoringRuleTypeCreate"] = SecurityMonitoringRuleTypeCreate


class SecurityMonitoringRuleCreatePayload(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "cases": ([SecurityMonitoringRuleCaseCreate],),
            "filters": ([SecurityMonitoringFilter],),
            "has_extended_title": (bool,),
            "is_enabled": (bool,),
            "message": (str,),
            "name": (str,),
            "options": (SecurityMonitoringRuleOptions,),
            "queries": ([SecurityMonitoringRuleQueryCreate],),
            "tags": ([str],),
            "type": (SecurityMonitoringRuleTypeCreate,),
        }

    attribute_map = {
        "cases": "cases",
        "is_enabled": "isEnabled",
        "message": "message",
        "name": "name",
        "options": "options",
        "queries": "queries",
        "filters": "filters",
        "has_extended_title": "hasExtendedTitle",
        "tags": "tags",
        "type": "type",
    }

    read_only_vars = {}

    def __init__(self, cases, is_enabled, message, name, options, queries, *args, **kwargs):
        """SecurityMonitoringRuleCreatePayload - a model defined in OpenAPI

        Args:
            cases ([SecurityMonitoringRuleCaseCreate]): Cases for generating signals.
            is_enabled (bool): Whether the rule is enabled.
            message (str): Message for generated signals.
            name (str): The name of the rule.
            options (SecurityMonitoringRuleOptions):
            queries ([SecurityMonitoringRuleQueryCreate]): Queries for selecting logs which are part of the rule.

        Keyword Args:
            filters ([SecurityMonitoringFilter]): [optional] Additional queries to filter matched events before they are processed.
            has_extended_title (bool): [optional] Whether the notifications include the triggering group-by values in their title.
            tags ([str]): [optional] Tags for generated signals.
            type (SecurityMonitoringRuleTypeCreate): [optional]
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.cases = cases
        self.is_enabled = is_enabled
        self.message = message
        self.name = name
        self.options = options
        self.queries = queries

    @classmethod
    def _from_openapi_data(cls, cases, is_enabled, message, name, options, queries, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SecurityMonitoringRuleCreatePayload, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.cases = cases
        self.is_enabled = is_enabled
        self.message = message
        self.name = name
        self.options = options
        self.queries = queries
        return self
